@@ -14,7 +14,7 @@ import tempfile
 from kombu.utils.encoding import safe_repr
 
 from celery.exceptions import WorkerShutdown
-from celery.five import UserDict, items
+from celery.five import UserDict, items, string_t
 from celery.platforms import signals as _signals
 from celery.utils import timeutils
 from celery.utils.functional import maybe_list
@@ -275,10 +275,13 @@ def hello(state, from_node, revoked=None, **kwargs):
 
 
 @Panel.register
-def dump_tasks(state, taskinfoitems=None, **kwargs):
-    tasks = state.app.tasks
+def dump_tasks(state, taskinfoitems=None, builtins=False, **kwargs):
+    reg = state.app.tasks
     taskinfoitems = taskinfoitems or DEFAULT_TASK_INFO_ITEMS
 
+    tasks = reg if builtins else (
+        task for task in reg if not task.startswith('celery.'))
+
     def _extract_info(task):
         fields = dict((field, str(getattr(task, field, None)))
                       for field in taskinfoitems
@@ -288,7 +291,7 @@ def dump_tasks(state, taskinfoitems=None, **kwargs):
             return '{0} [{1}]'.format(task.name, ' '.join(info))
         return task.name
 
-    return [_extract_info(tasks[task]) for task in sorted(tasks)]
+    return [_extract_info(reg[task]) for task in sorted(tasks)]
 
 
 @Panel.register
@@ -364,7 +367,9 @@ def active_queues(state):
 
 
 def _wanted_config_key(key):
-    return key.isupper() and not key.startswith('__')
+    return (isinstance(key, string_t) and
+            key.isupper() and
+            not key.startswith('__'))
 
 
 @Panel.register
