@@ -5,6 +5,7 @@ from sphinx.environment import NoUri
 APPATTRS = {
     'amqp': 'celery.app.amqp.AMQP',
     'backend': 'celery.backends.base.BaseBackend',
+    'conf': 'celery.app.utils.Settings',
     'control': 'celery.app.control.Control',
     'events': 'celery.events.Events',
     'loader': 'celery.app.loaders.base.BaseLoader',
@@ -13,15 +14,31 @@ APPATTRS = {
     'tasks': 'celery.app.registry.Registry',
 
     'AsyncResult': 'celery.result.AsyncResult',
+    'ResultSet': 'celery.result.ResultSet',
     'GroupResult': 'celery.result.GroupResult',
     'Worker': 'celery.apps.worker.Worker',
     'WorkController': 'celery.worker.WorkController',
     'Beat': 'celery.apps.beat.Beat',
     'Task': 'celery.app.task.Task',
-    'send_task': 'celery.Celery.send_task',
-    'connection': 'celery.Celery.connection',
+    'signature': 'celery.canvas.Signature',
 }
 
+APPDIRECT = set([
+    'on_configure', 'on_after_configure', 'on_after_finalize',
+    'set_current', 'set_default', 'close', 'on_init', 'start',
+    'worker_main', 'task', 'gen_task_name', 'finalize',
+    'add_defaults', 'config_from_object', 'config_from_envvar',
+    'config_from_cmdline', 'setup_security', 'autodiscover_tasks',
+    'send_task', 'connection', 'connection_or_acquire',
+    'producer_or_acquire', 'prepare_config', 'now', 'mail_admins',
+    'select_queues', 'either', 'bugreport', 'create_task_cls',
+    'subclass_with_self', 'annotations', 'current_task', 'oid',
+    'timezone', '__reduce_keys__', 'fixups', 'finalized', 'configured',
+    'autofinalize', 'steps', 'user_options', 'main', 'clock',
+])
+
+APPATTRS.update(dict((x, 'celery.Celery.{0}'.format(x)) for x in APPDIRECT))
+
 ABBRS = {
     'Celery': 'celery.Celery',
 }
@@ -43,7 +60,7 @@ def shorten(S, newtarget, src_dict):
         return S[2:]
     elif S.startswith('@'):
         if src_dict is APPATTRS:
-            return '.'.join([pkg_of(newtarget), S[1:]])
+            return '.'.join(['app', S[1:]])
         return S[1:]
     return S
 
